@@ -49,12 +49,14 @@ int main(int argc, char **argv)
         "   $ kscreen-doctor output.HDMI-2.mode.1920x1080@60 \n"
         "\n   Set scale (note: fractional scaling is only supported on wayland)\n"
         "   $ kscreen-doctor output.HDMI-2.scale.2 \n"
-        "\n   Set rotation (possible values: none, left, right, inverted)\n"
+        "\n   Set rotation (possible values: none, left, right, inverted, flipped, flipped90, flipped180, flipped270)\n"
         "   $ kscreen-doctor output.HDMI-2.rotation.left \n"
         "\n   Set HDR mode (possible values: enable, disable)\n"
         "   $ kscreen-doctor output.HDMI-2.hdr.enable\n"
         "\n   Set SDR brightness (possible values: 100-1000)\n"
         "   $ kscreen-doctor output.HDMI-2.sdr-brightness.300\n"
+        "\n   Set brightness on non HDR screens (possible values: 0-100)\n"
+        "   $ kscreen-doctor output.HDMI-2.brightness.10\n"
         "\n   Set wide color gamut mode (possible values: enable, disable)\n"
         "   $ kscreen-doctor output.HDMI-2.wcg.enable\n"
         "\n   Set ICC profile path\n"
@@ -62,7 +64,11 @@ int main(int argc, char **argv)
         "   Show dpms information:\n"
         "   $ kscreen-doctor --dpms show\n\n"
         "   Set dpms mode: (possible values: on, off)\n"
-        "   $ kscreen-doctor --dpms on");
+        "   $ kscreen-doctor --dpms on\n"
+        "   Add a custom mode: (arguments: width,height,refresh rate in mHz,blanking 'reduced' or 'full')\n"
+        "   $ kscreen-doctor output.1.addCustomMode.1920.1080.75000.full\n"
+        "   Remove a custom mode: (arguments: index in the custom mode list)\n"
+        "   $ kscreen-doctor output.1.removeCustomMode.0");
     /*
         "\nError codes:\n"
         "   2 : general parse error\n"
